@@ -12,9 +12,13 @@ from synthaser import (
     models,
     parsers,
     download,
+    config,
+    classify
 )
 from synthaser.plot import plot_synthases
 
+from Bio import Entrez
+
 logging.basicConfig(
     format="[%(asctime)s] %(levelname)s - %(message)s", datefmt="%H:%M:%S"
 )
@@ -40,9 +44,9 @@ def synthaser(
     evalue=None,
     maxhit=None,
     dmode=None,
-    domain_file=None,
-    classify_file=None,
+    rule_file=None,
     results_file=None,
+    reclassify=False
 ):
     """Run synthaser."""
     # Set flag to prevent re-writing the JSON we load from
@@ -53,6 +57,9 @@ def synthaser(
         with open(json_file) as fp:
             synthases = models.SynthaseContainer.from_json(fp)
         _json_loaded = True
+        if reclassify:
+            LOG.info("Reclassifying synthases in JSON file")
+            classify.classify(synthases, rule_file=rule_file)
     else:
         try:
             synthases = search.search(
@@ -60,8 +67,7 @@ def synthaser(
                 query_file=query_file,
                 query_ids=query_ids,
                 cdsid=cdsid,
-                domain_file=domain_file,
-                classify_file=classify_file,
+                rule_file=rule_file,
                 results_file=results_file,
                 database=database,
                 smode=smode,
@@ -92,10 +98,18 @@ def synthaser(
 
 
 def main():
-    LOG.info("Starting synthaser")
-
     args = parsers.parse_args(sys.argv[1:])
 
+    LOG.info("Starting synthaser")
+    if args.command in ("getseq", "getdb", "search"):
+        # Set up mandatory Entrez params
+        cfg = config.get_config_parser()
+        Entrez.email = cfg["synthaser"].get("email", None)
+        Entrez.api_key = cfg["synthaser"].get("api_key", None)
+
+        if not Entrez.email and not Entrez.api_key:
+            raise IOError("No e-mail or NCBI API key found, please run synthaser config")
+
     if args.command == "getdb":
         download.getdb(args.database, args.folder)
 
@@ -128,9 +142,9 @@ def main():
             evalue=args.evalue,
             maxhit=args.maxhit,
             dmode=args.dmode,
-            domain_file=args.domain_file,
-            classify_file=args.classify_file,
+            rule_file=args.rule_file,
             results_file=args.results_file,
+            reclassify=args.reclassify,
         )
 
     elif args.command == "extract":
@@ -146,6 +160,18 @@ def main():
             mode=args.mode,
         )
 
+    elif args.command == "config":
+        if not args.email and not args.api_key:
+            LOG.info(
+                "No e-mail or API key specified; if this is your first time"
+                " running synthaser config, please make sure you provide one."
+            )
+        config.write_config_file(
+            email=args.email,
+            api_key=args.api_key,
+            max_tries=args.max_tries,
+        )
+
     LOG.info("Done!")
 
 
